"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserManager = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const CachedManager_1 = require("./CachedManager");
const iFunnyError_1 = require("../errors/iFunnyError");
const User_1 = require("../structures/User");
/**
 * Manages iFunny Users
 * @extends CachedManager<User>
 */
class UserManager extends CachedManager_1.CachedManager {
    /**
     * @param client Client instance attached to the UserManager
     */
    constructor(client, cacheConfig) {
        super(client, User_1.User, cacheConfig);
    }
    /**
     * Checks if a nick is available or if it's taken by another user\
     * It's a good idea to check this before signing up or changing your nick
     * @param nick Nick to check availability of
     */
    async isNickAvailable(nick) {
        const { data } = await this.client.instance.get(ifunny_api_types_1.Endpoints.nicksAvailable, {
            params: {
                nick,
            },
        });
        return data.data.available;
    }
    /**
     * Checks if an email is available or if it's taken by another user\
     * It's a good idea to check this before signing up or changing your email
     * @param email Email to check availability of
     */
    async isEmailAvailable(email) {
        const { data } = await this.client.instance.get(ifunny_api_types_1.Endpoints.emailsAvailable, {
            params: { email },
        });
        return data.data.available;
    }
    /**
     * Fetches a user by their ID or Nick
     * @param idOrNick Id or nick of the user
     * @param byNick Whether to lookup by nick (Default: false)
     * @param cached Whater to return the cached result (Default: true)
     * @returns User|null if the client is authorized
     * @throws iFunnyError
     */
    async fetch(idOrNick, byNick = false, cached = true) {
        try {
            let user = await this.resolve(idOrNick);
            if (cached && user)
                return user;
            const { data } = await this.client.instance.request({
                url: ifunny_api_types_1.Endpoints.user(idOrNick, byNick),
            });
            if (!data)
                return data;
            user = new User_1.User(this.client, data.data);
            this.cache.set(user.id, user);
            this.cache.set(user.nick, user);
            return user;
        }
        catch (error) {
            if (error instanceof iFunnyError_1.iFunnyError) {
                if (error.code === ifunny_api_types_1.IFUNNY_ERRORS.NOT_FOUND)
                    return null;
            }
            throw error;
        }
    }
}
exports.UserManager = UserManager;
exports.default = UserManager;
//# sourceMappingURL=UserManager.js.map